@@ -110,6 +110,8 @@ def cmd():
         "[10] df['new column'] = df['existing column'] + 100 | 'add a new column' \n"
         "[11] pip show (package name) | 'show package details'\n"
         "[12] data.loc[(data['para1'] == x) & (data['para-3']>xx)]\n"
+        "[13] df.describe() | 'show dataframe basic statistics values'\n"
+        "[14] df.info() | 'show dataframe basic summary'\n"
     )
 
 
@@ -1576,7 +1578,6 @@ def scatter09lr6sigma(df, parameter_x, parameter_y, sigma, title):
     plt.show()
 
 
-# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> [to be validated. update:12/28]
 # normality test. input target list is enough
 def normaltest(targetlist):
     import numpy as np
@@ -1618,18 +1619,83 @@ def parallel(df, category, title):
     plt.show()
 
 
+# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> [to be validated. update:12/28]
+
+# heatmap - show correlation of each parameter
+def heatmap(df, title):
+    import seaborn as sns
+    import numpy as np
+    import matplotlib.pyplot as plt
+
+    df = df
+
+    plt.figure(figsize=(12, 8))
+    sns.heatmap(df.corr(), xticklabels=df.corr().columns, yticklabels=df.corr().columns, linewidth=1, linecolor='white',
+                cmap='Blues', center=0, annot=True)
+    plt.title(title)
+    plt.xticks(rotation=30)
+    plt.yticks(rotation=30)
+    plt.show()
+
+
+# matrix plot: 1.scatter + hist; 2.scatter + kde; 3.kde + kde
+def matrix01(df, other_matrix_type, upperleft_diag_matrix_type):
+    import seaborn as sns
+    import numpy as np
+    import matplotlib.pyplot as plt
+
+    df = df
+
+    print(df.info())
+    plt.figure(figsize=(12, 8))
+
+    kind = other_matrix_type;
+    diag_kind = upperleft_diag_matrix_type;
+
+    if kind == 'scatter' and diag_kind == 'hist':
+
+        g = sns.pairplot(
+            df, kind=kind, diag_kind=diag_kind,
+            plot_kws=dict(s=90, edgecolor="white", alpha=.5, linewidth=1),
+            diag_kws=dict(edgecolor="white", alpha=.8, linewidth=1.5))
+
+    elif kind == 'scatter' and diag_kind == 'kde':
+        g = sns.pairplot(
+            df, kind=kind, diag_kind=diag_kind,
+            plot_kws=dict(s=80, edgecolor="white", alpha=.5, linewidth=1))
+    #             diag_kws=dict(edgecolor="white",alpha=.8,linewidth=1.5))
+
+    elif kind == 'kde' and diag_kind == 'kde':
+
+        g = sns.pairplot(df, diag_kind="kde",
+                         plot_kws=dict(s=80, edgecolor="white", alpha=.5, linewidth=1),
+                         )  # kde-核密度估计图
+        g.map_lower(sns.kdeplot, levels=5, color="grey")
+
+    else:
+        nothing = 'do nothing'
+
+    for ax in g.axes.flat:
+        ax.grid(True, axis='both', alpha=0.3)
+
+    plt.show()
+
+
+
+
 # show correlation line + error zone. with scatter plot:
 
 
 # [planning ↓]
 
-# heatmap() / correlation map
+
 # Line plot (x-时间序列: 4.移动平均图 Arima  5.时间序列预测 等种种）
 # my.data analytics ppt里的图表
 # 多因子相关性矩阵图/
-# SSAP用户报告里绘制的图
+# 用户报告里绘制的图
 # 多项式回归拟合
 # 聚类算法 DBSCAN.
 # regression model:
 # 多元线性回归：https://cloud.tencent.com/developer/article/1059976
-# 移动平均模型（ARIMA）
\ No newline at end of file
+# 移动平均模型（ARIMA）
+# 时间序列预测图：自相关性，异方差性等等
\ No newline at end of file
